==> nextcloud-15.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/eo.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Eraro okazis dum generado de viaj rezervkodoj",
    "{name} backup codes" : "{name} rezervkodoj",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Jen viaj rezervkodoj. Bv. konservi aŭ presi ilin, ĉar vi ne plu povos vidi tiujn kodojn poste",
    "Save backup codes" : "Konservi la rezervkodojn",
    "Print backup codes" : "Presi la rezervkodojn",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Rezervkodoj generiĝis. {used} kodoj el {total} uziĝis.",
    "Regenerate backup codes" : "Regeneri rezervkodojn",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vi regeneras rezervkodojn, vi aŭtomate senvalidigas la antaŭajn.",
    "Generate backup codes" : "Generi rezervkodojn",
    "You created two-factor backup codes for your account" : "Vi kreis dufazajn rezervkodojn por via konto",
    "Second-factor backup codes" : "Dufazaj rezervkodoj",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Vi ŝaltis dufazan aŭtentigon, sed vi ankoraŭ ne generis rezervkodojn. Nepre faru tion tuj por eviti, ke vi ne povos ensaluti okaze de perdo de via duan fazo.",
    "Backup code" : "Rezervkodo",
    "Use backup code" : "Uzi rezervkodon",
    "Two factor backup codes" : "Dufazaj rezervkodoj",
    "A two-factor auth backup codes provider" : "Provizanto de rezervkodoj por dufaza aŭtentigo",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uzu unu el viaj rezervkodoj, kiujn vi konservis dum agordo de dufaza aŭtentigo.",
    "Submit" : "Sendi",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Rezervkodoj generiĝis. {{used}} kodoj el {{total}} uziĝis.",
    "Nextcloud backup codes" : "Rezervkodoj por Nextcloud"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/eo.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Eraro okazis dum generado de viaj rezervkodoj",
    "{name} backup codes" : "{name} rezervkodoj",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Jen viaj rezervkodoj. Bv. konservi aŭ presi ilin, ĉar vi ne plu povos vidi tiujn kodojn poste",
    "Save backup codes" : "Konservi la rezervkodojn",
    "Print backup codes" : "Presi la rezervkodojn",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Rezervkodoj generiĝis. {used} kodoj el {total} uziĝis.",
    "Regenerate backup codes" : "Regeneri rezervkodojn",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vi regeneras rezervkodojn, vi aŭtomate senvalidigas la antaŭajn.",
    "Generate backup codes" : "Generi rezervkodojn",
    "You created two-factor backup codes for your account" : "Vi kreis dufazajn rezervkodojn por via konto",
    "Second-factor backup codes" : "Dufazaj rezervkodoj",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Vi ŝaltis dufazan aŭtentigon, sed vi ankoraŭ ne generis rezervkodojn. Nepre faru tion tuj por eviti, ke vi ne povos ensaluti okaze de perdo de via duan fazo.",
    "Backup code" : "Rezervkodo",
    "Use backup code" : "Uzi rezervkodon",
    "Two factor backup codes" : "Dufazaj rezervkodoj",
    "A two-factor auth backup codes provider" : "Provizanto de rezervkodoj por dufaza aŭtentigo",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uzu unu el viaj rezervkodoj, kiujn vi konservis dum agordo de dufaza aŭtentigo.",
    "Submit" : "Sendi",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Rezervkodoj generiĝis. {{used}} kodoj el {{total}} uziĝis.",
    "Nextcloud backup codes" : "Rezervkodoj por Nextcloud",
    "activated" : "ŝaltita",
    "updated" : "ĝisdatigita",
    "mounted" : "muntita",
    "deactivated" : "malŝaltita",
    "beforeCreate" : "beforeCreate",
    "created" : "kreita",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "detruita",
    "beforeMount" : "beforeMount"
},
"nplurals=2; plural=(n != 1);");
